% example Quokka3 settingsfile
% theoretical cell consisting of SiO2 + poly-Si contacts with direct
% tunneling transport only (pinhole transport neglected)
% uses the full 1D drift-diffusion solver
%
% The front n-type considers a direct tunneling transport limitation,
% assuming the poly-Si itself to be "metal-like", i.e. not having any
% band-bending itself.
%
% The rear side considers band-bending also within the poly-Si layer, which
% reduces band-bending in the c-Si wafer. This also resolves the influence
% of doping on band-bending, instead of defining a fixed workfunction. This
% can however not be combined with a tunneling model at the moment.
%
% This example also models parasitic absorption in the poly-Si layers. I.e.
% when one changes e.g. doping density, both recombination (via changed
% band-bending) and parasitic absorption are affected.
%
% (c) 2023 Andreas Fell


Syntax = 'generic';

Domain.DeviceType = 'semiconductor device';
Domain.Dimensions = 1;
Domain.Wz = 150 um;

Solver.SolutionType = 'light JV-curve';
Solver.JVCurve.VtermStepSize = 'standard';
Solver.Electrical.VocGuess = 0.7;

Solver.Electrical.MetalModelType = 'constant-potential';
Solver.Electrical.BulkModelType = 'full';

Thermal.T = 298;

Bulk.BackgroundDoping.SettingType = 'dopingtype-resistivity';
Bulk.BackgroundDoping.DopingType = 'n-type';
Bulk.BackgroundDoping.Resistivity = 1;
Bulk.Electrical.Recombination.Type = 'intrinsic';

Optical.GenerationModelType = 'Text-Z';
Optical.FrontIllumination.Enable = 1;
Optical.FrontIllumination.Spectrum.Type = 'AM1.5g';
Optical.FrontIllumination.Scale = 1;
Optical.RearIllumination.Enable = 0;
Optical.TextZ.FrontText.Type = 'Text';
Optical.TextZ.FrontText.Text.Type = 'file';
Optical.TextZ.FrontText.Text.File = 'TOPCon_Text.csv';
Optical.TextZ.FrontText.FacetAngle = 54;
Optical.TextZ.FrontZ.Type = 'local';


% front n-type TOPCon
SkinFeature(1).Name = 'front skin';
SkinFeature(1).Geometry.Plane = 'front';
SkinFeature(1).Lumped.Optical.Internal.Rint = 0.92;
SkinFeature(1).Lumped.Optical.Internal.Diffuse = 0;
SkinFeature(1).Lumped.Optical.Internal.ApppType = 'from layers'; % account for parasitic absorption via the layer properties of this skin
SkinFeature(1).ElectricalModelType = 'detailed';
SkinFeature(1).Layer(1).Name = 'in-diffusion';
SkinFeature(1).Layer(1).Type = 'near-surface';
SkinFeature(1).Layer(1).ApppType = 'off'; % no FCA without in-diffusion; if in-diffusion is considered, change this to 'model'
SkinFeature(1).Layer(1).DopingProfile.Type = 'off'; % no doping into c-Si is assumed
SkinFeature(1).Layer(1).SurfaceRecombination.Type = 'S';
SkinFeature(1).Layer(1).SurfaceRecombination.Sn = 1e2; % doesn't matter for n-type poly
SkinFeature(1).Layer(1).SurfaceRecombination.Sp = 1e2; % this value matters for n-type poly
SkinFeature(1).Layer(1).SurfaceRecombination.Et_Ei = 0;
SkinFeature(1).Layer(2).Name = 'poly-Si';
SkinFeature(1).Layer(2).Type = 'transport';
SkinFeature(1).Layer(2).Material = 'Si';
SkinFeature(1).Layer(2).ApppType = 'model';
SkinFeature(1).Layer(2).ConductionType = 'n-type';
SkinFeature(1).Layer(2).Thickness = 100 nm;
SkinFeature(1).Layer(2).DopingDensityType = 'user';
SkinFeature(1).Layer(2).DopingDensity = 1e20;
SkinFeature(1).Layer(2).Interface.BarrierHeightType = 'user'; % input empirical value for barrier height; this is better than calculating it from material properties each side due to barrier-lowering effects happening in reality
SkinFeature(1).Layer(2).Interface.BarrierHeight = 0.17;
SkinFeature(1).Layer(2).Interface.Insulator.Enable = 1;
SkinFeature(1).Layer(2).Interface.Insulator.Thickness = 1.4 nm;
SkinFeature(1).Layer(2).Interface.Insulator.ElectronBarrier = 3.2;
SkinFeature(1).Layer(2).Interface.Insulator.ElectronEffectiveMass = 0.27;
SkinFeature(1).Layer(2).Interface.Insulator.RelativePermittivity = 3.9;
SkinFeature(1).Layer(2).Interface.OhmicResistivity = 20; % ohmic contact resistivity parallel to tunneling / thermionic emission; can represent pinhole transport


% rear p-type TOPCon
SkinFeature(2).Name = 'rear skin';
SkinFeature(2).Geometry.Plane = 'rear';
SkinFeature(2).Lumped.Optical.Internal.Rint = 0.92;
SkinFeature(2).Lumped.Optical.Internal.Diffuse = 0;
SkinFeature(2).Lumped.Optical.Internal.ApppType = 'from layers'; % account for parasitic absorption via the layer properties of this skin
SkinFeature(2).ElectricalModelType = 'detailed';
SkinFeature(2).Layer(1).Name = 'in-diffusion';
SkinFeature(2).Layer(1).Type = 'near-surface';
SkinFeature(2).Layer(1).ApppType = 'off';
SkinFeature(2).Layer(1).DopingProfile.Type = 'off'; % no doping into c-Si is assumed
SkinFeature(2).Layer(1).SurfaceRecombination.Type = 'S';
SkinFeature(2).Layer(1).SurfaceRecombination.Sn = 1e2; % this value matters for p-type poly
SkinFeature(2).Layer(1).SurfaceRecombination.Sp = 1e2; % doesn't matter for n-type poly
SkinFeature(2).Layer(1).SurfaceRecombination.Et_Ei = 0;
SkinFeature(2).Layer(2).Name = 'poly-Si';
SkinFeature(2).Layer(2).Type = 'transport';
SkinFeature(2).Layer(2).ApppType = 'model';
SkinFeature(2).Layer(2).TLModelType = 'analytic band-bending'; % assumption for this model to be accurate: highly doped layer (injection << doping), thickness > Debye length
SkinFeature(2).Layer(2).DopingDensityType = 'user';
SkinFeature(2).Layer(2).DopingDensity = 1e19;
SkinFeature(2).Layer(2).EactType = 'from DOS and doping'; % activation energy required for the analytical band-bending model is calculated from doping and density of states of this layer's material
SkinFeature(2).Layer(2).Material = 'Si';
SkinFeature(2).Layer(2).ConductionType = 'p-type';
SkinFeature(2).Layer(2).Thickness = 100 nm;
SkinFeature(2).Layer(2).Interface.OhmicResistivity = 1e10; % no parallel contact resistivity required; thermionic emission is very effective without a tunneling layer, i.e. there is a low contact resistance anyway

ContactFeature(1).Name = 'front contact';
ContactFeature(1).Geometry.Plane = 'front';

MetalFeature(1).Name = 'front metal';
MetalFeature(1).Geometry.Plane = 'front';
MetalFeature(1).Electrical.Polarity = 'n-type';

ContactFeature(2).Name = 'rear contact';
ContactFeature(2).Geometry.Plane = 'rear';

MetalFeature(2).Name = 'rear metal';
MetalFeature(2).Geometry.Plane = 'rear';
MetalFeature(2).Electrical.Polarity = 'p-type';
